CCL: /home/chisarie/Documents/lsst_ccl/CCL/tests/ccl_test_eh.c File Reference

CCL

Macros | Functions
ccl_test_eh.c File Reference
`#include "ccl.h"`
`#include "ctest.h"`
`#include <stdio.h>`
`#include <math.h>`

## Macros
#define | EH_TOLERANCE 1.0E-4

## Functions
| CTEST_DATA (eh)
| CTEST_SETUP (eh)
| CTEST2 (eh, model_1)

## Macro Definition Documentation

## ◆ EH_TOLERANCE

#define EH_TOLERANCE 1.0E-4

## Function Documentation

## ◆ CTEST2()

CTEST2 | ( | eh | ,
|  | model_1 |
| ) |  |

## ◆ CTEST_DATA()

CTEST_DATA | ( | eh |  | ) |

## ◆ CTEST_SETUP()

CTEST_SETUP | ( | eh |  | ) |